@@ -1,10 +1,10 @@
 /*
- * bridge.h - header for bridge.c
- * $Id: bridge.h,v 1.4 2003/01/26 09:09:07 rdenisc Exp $
+ * bridge.h - header for bridge.cpp
+ * $Id: bridge.h,v 1.8 2004/06/05 15:15:17 rdenisc Exp $
  */
 
 /***********************************************************************
- *  Copyright (C) 2002-2003 Rmi Denis-Courmont.                       *
+ *  Copyright (C) 2002-2004 Remi Denis-Courmont.                       *
  *  This program is free software; you can redistribute and/or modify  *
  *  it under the terms of the GNU General Public License as published  *
  *  by the Free Software Foundation; version 2 of the license.         *
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               *
  *  See the GNU General Public License for more details.               *
  *                                                                     *
- *  You should have received a copy of the GNU General Pulic License   *
+ *  You should have received a copy of the GNU General Public License  *
  *  along with this program; if not, you can get it from:              *
  *  http://www.gnu.org/copyleft/gpl.html                               *
  ***********************************************************************/
@@ -23,8 +23,11 @@
 
 # define __TCPREEN_BRIDGE_H
 
+# ifndef __cplusplus
+#  error C++ only header
+# endif
 # include "log.h"
 
-int monitor_bridge(int fd[4], DataLogList *logs, long limit);
+int monitor_bridge(const int *fd, DataLogList *logs, long limit);
 
 #endif
