@@ -1,10 +1,10 @@
 /*
- * tcpreen.h - header for tcpreen.c
- * $Id: tcpreen.h,v 1.6 2003/01/26 09:09:08 rdenisc Exp $
+ * tcpreen.h - header for tcpreen.cpp
+ * $Id: tcpreen.h,v 1.14 2004/06/05 15:15:18 rdenisc Exp $
  */
 
 /***********************************************************************
- *  Copyright (C) 2002-2003 Rmi Denis-Courmont.                       *
+ *  Copyright (C) 2002-2003 Remi Denis-Courmont.                       *
  *  This program is free software; you can redistribute and/or modify  *
  *  it under the terms of the GNU General Public License as published  *
  *  by the Free Software Foundation; version 2 of the license.         *
@@ -14,7 +14,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               *
  *  See the GNU General Public License for more details.               *
  *                                                                     *
- *  You should have received a copy of the GNU General Pulic License   *
+ *  You should have received a copy of the GNU General Public License  *
  *  along with this program; if not, you can get it from:              *
  *  http://www.gnu.org/copyleft/gpl.html                               *
  ***********************************************************************/
@@ -22,33 +22,31 @@
 #ifndef __TCPREEN_TCPREEN_H
 
 # define _TCPREEN_TCPREEN_H
-# ifdef HAVE_SYS_TYPES_H
-#  include <sys/types.h> /* uid_t */
-# endif
+# include <sys/types.h> /* uid_t */
 
 # include "log.h"
-# include "socketinfo.h"
+
 
 enum
 {
 	tcpreen_normal=0x00,
-	tcpreen_listen_both=0x01,
-	tcpreen_connect_both=0x02,
-	tcpreen_reversed=0x03, /* warning */
-	tcpreen_numeric=0x04,
+	tcpreen_numeric=0x01,
+	tcpreen_listen_server=0x02,
+	tcpreen_listen_client=0x04,
 	tcpreen_daemon=0x08,
-	tcpreen_syslog=0x10,
 	tcpreen_verbose=0x20,
-	tcpreen_speak=0x30
+	tcpreen_speak=0x28
 };
 
+
 struct bridgeconf
 {
-	struct sockhostinfo server, bridge;
-	DataLogListMaker *logmaker;
+	const char *servername, *bridgename, *serverservice, *bridgeservice;
+	int serveraf, bridgeaf;
+	const DataLogListMaker *logsmaker;
 	int mode, maxclients;
 	long bytelimit, totalclients;
-	uid_t priv, unpriv;
+	uid_t user;
 };
 
 int bridge_main (const struct bridgeconf *conf);
